"""tuat-feed
農工大の掲示板のデータを取得するライブラリです。使い方としては次のように使うことができます。

>>> import tuat_feed
>>> feed = tuat_feed.fetch_technology() # 工学部掲示板情報の取得
# >>> feed = tuat_feed.fetch_agriculture() # 農学部掲示板情報の取得
>>> len(feed)
40
>>> feed[0]
Post(...)
"""

from .fetch import fetch, fetch_technology, fetch_agriculture



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tuat_feed']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.26.0,<3.0.0']

setup_kwargs = {
    'name': 'tuat-feed',
    'version': '0.2.4',
    'description': 'Unofficial library for fetching the feed for TUAT',
    'long_description': '# (非公式)TUAT掲示板ライブラリ\n\n[![test](https://github.com/pineapplehunter/tuat-feed/actions/workflows/test.yml/badge.svg)](https://github.com/pineapplehunter/tuat-feed/actions/workflows/test.yml) [![doc](https://api.netlify.com/api/v1/badges/77818cbd-dd98-4969-ab2d-2d4c6800434f/deploy-status)](https://app.netlify.com/sites/tuat-feed-doc/deploys) [![PyPI version](https://badge.fury.io/py/tuat-feed.svg)](https://badge.fury.io/py/tuat-feed)\n\n## ドキュメント\nhttps://tuat-feed-doc.netlify.app/tuat_feed.html\n\n## インストール\n* `python` >= 3.7\n\n```sh\n$ pip install tuat-feed\n```\n\n## 使い方\n\n```python\n>>> import tuat_feed\n>>> feed = tuat_feed.fetch_technology() # 工学部掲示板情報の取得\n# >>> feed = tuat_feed.fetch_agriculture() # 農学部掲示板情報の取得\n>>> len(feed)\n40\n>>> feed[0]\nPost(...)\n```\n',
    'author': 'Shogo Takata',
    'author_email': 's196643z@st.go.tuat.ac.jp',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/pineapplehunter/tuat-feed',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from typing import List
from tuat_feed.post import Post
import requests


def fetch(
    gakubu="technology",
    category: str = "all",
    url: str = "https://api.ihavenojob.work/tuat",
) -> List[Post]:
    """投稿の取得

    Parameters
    ----------
    gakubu : str, optional学部。"technology", "agriculture"。デフォルトは"technology"。
        取得する
    category : str, optional
        取得する投稿の種類。"all", "campus", "academic"。デフォルトでは"all"。
    url : str, optional
        データを取得するAPIのURL、デフォルトでは"https://api.ihavenojob.work/tuat/"

    Returns
    -------
    List[Post]
        投稿の一覧

    Raises
    ------
    ValueError
        gakubu, categoryに規定外の入力があった場合
    """

    if gakubu == "technology":
        G = "Technology"
    elif gakubu == "agriculture":
        G = "Agriculture"
    else:
        raise ValueError(
            f'gakubu must be one of "technology" or "agriculture". {gakubu} was supplied.'
        )

    if category == "all":
        response = requests.get(url + f"/v2/?gakubu={G}&category=All")
    elif category == "academic":
        response = requests.get(url + f"/v2/?gakubu={G}&category=Academic")
    elif category == "campus":
        response = requests.get(url + f"/v2/?gakubu={G}&category=Campus")
    else:
        raise ValueError(
            f'category must be one of "all", "academic" or "campus". {category} was supplied.'
        )

    feed = response.json()
    posts = []
    for p in feed:
        posts.append(Post.parse_post(p))
    return posts


def fetch_technology(
    category: str = "all",
    url: str = "https://api.ihavenojob.work/tuat/",
) -> List[Post]:
    """工学部掲示板情報の取得

    Parameters
    ----------
    category : str, optional
        情報のカテゴリ。詳細は`fetch`を確認してください。
    url : str, optional
        API URL詳細は`fetch`を確認してください。

    Returns
    -------
    List[Post]
        投稿の一覧

    Raises
    ------
    ValueError
        gakubu, categoryに規定外の入力があった場合
    """
    return fetch(gakubu="technology", category=category, url=url)


def fetch_agriculture(
    category: str = "all",
    url: str = "https://api.ihavenojob.work/tuat/",
) -> List[Post]:
    """工学部掲示板情報の取得

    Parameters
    ----------
    category : str, optional
        情報のカテゴリ。詳細は`fetch`を確認してください。
    url : str, optional
        API URL詳細は`fetch`を確認してください。

    Returns
    -------
    List[Post]
        投稿の一覧

    Raises
    ------
    ValueError
        gakubu, categoryに規定外の入力があった場合
    """
    return fetch(gakubu="agriculture", category=category, url=url)
